"""
Initializes the game_master package and provides access to various game functions.
"""

from .game_master import show_help
from .game_master import spin_the_bottle
from .game_master import countdown
from .game_master import random_dare
from .game_master import random_multiple_people_punishment
from .game_master import random_game_idea
from .game_master import random_truth
from .game_master import who_pays_the_bill
